==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/sq.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Temë me kontrast të lartë",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Një temë e kontrastit të lartë për të lehtësuar navigimin tuaj. Cilësia vizuale do të reduktohet, por qartësia do të rritet.",
    "Dark theme (beta)" : "Tema e errët (beta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Një temë e errët për të lehtësuar sytë duke ulur shkëlqimin dhe ndritshmërinë e përgjithshme. Është ende në zhvillim, prandaj ju lutemi raportoni çdo çështje që mund të gjeni.",
    "Dyslexia font" : "Fonti Dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic është një font / karakter tipografik i lirë i dizajnuar për të zbutur disa nga gabimet e zakonshme të leximit të shkaktuara nga disleksija.",
    "Accessibility" : "Aksesueshmëria",
    "Accessibility options for nextcloud" : "Opsionet e aksesueshmërisë për nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Mundëson shumë opsione të aksesueshmërisë që t'ju lehtësojë përdorimin e Nextcloud",
    "Web Content Accessibility Guidelines" : "Udhëzimet për Aksesueshmërinë e Përmbajtjes së Rrjetit",
    "our issue tracker" : "gjurmuesi ynë i çështjeve",
    "our design team" : "ekipi jonë i dizajnit",
    "Enable" : "Aktivizo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/sq.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Temë me kontrast të lartë",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Një temë e kontrastit të lartë për të lehtësuar navigimin tuaj. Cilësia vizuale do të reduktohet, por qartësia do të rritet.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Një temë e errët për të lehtësuar sytë duke ulur shkëlqimin dhe ndritshmërinë e përgjithshme. Është ende në zhvillim, prandaj ju lutemi raportoni çdo çështje që mund të gjeni.",
    "Dyslexia font" : "Fonti Dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic është një font / karakter tipografik i lirë i dizajnuar për të zbutur disa nga gabimet e zakonshme të leximit të shkaktuara nga disleksija.",
    "Accessibility" : "Aksesueshmëria",
    "Accessibility options for nextcloud" : "Opsionet e aksesueshmërisë për nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Mundëson shumë opsione të aksesueshmërisë që t'ju lehtësojë përdorimin e Nextcloud",
    "Web Content Accessibility Guidelines" : "Udhëzimet për Aksesueshmërinë e Përmbajtjes së Rrjetit",
    "our issue tracker" : "gjurmuesi ynë i çështjeve",
    "our design team" : "ekipi jonë i dizajnit",
    "Enable" : "Aktivizo",
    "Dark theme (beta)" : "Tema e errët (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic eshte nje font falas,  dizenjuar per te zvogeluar disa gabime te zakonshme te leximit te shkaktuara  nga Dyslexia. ",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Mundeson opsione te shumta aksesi per te fshire perdorimin tuaj te nextcloud",
    "Themes" : "Tema grafike",
    "Fonts" : "Fontet e shkrimit",
    "enabled" : "aktivizuar"
},
"nplurals=2; plural=(n != 1);");
